Stan Math Library: stan::math::common_type< std::vector< T1 >, std::vector< T2 > > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | List of all members
stan::math::common_type< std::vector< T1 >, std::vector< T2 > > Struct Template Reference

`#include <common_type.hpp>`

## Public Types
typedef std::vector< typename common_type< T1, T2 >::type > | type

## Detailed Description

### template<typename T1, typename T2>
struct stan::math::common_type< std::vector< T1 >, std::vector< T2 > >

Definition at line 18 of file common_type.hpp.

## Member Typedef Documentation

template<typename T1 , typename T2 >

typedef std::vector<typename common_type<T1, T2>::type> stan::math::common_type< std::vector< T1 >, std::vector< T2 > >::type

Definition at line 19 of file common_type.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/mat/fun/common_type.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.